From: "Brian C. Lane" <bcl@redhat.com>
This was causing the wrong url to be used when looking for RHUpdates/,
updates.img and product.img on an nfs .iso install.
NOTE: Tested along with fix for #741466
---
loader/nfsinstall.c | 6 ++++--
1 files changed, 4 insertions(+), 2 deletions(-)
diff --git a/loader/nfsinstall.c b/loader/nfsinstall.c
index d29e98a..f46e79e 100644
--- a/loader/nfsinstall.c
+++ b/loader/nfsinstall.c
@@ -123,12 +123,14 @@ static int nfsGetSetup(char ** hostptr, char ** dirptr, char ** optsptr) {
/* Parse nfs: url and return its componenets
*
- * nfs[

ptions]:<server>:<path>
+ * (nfs|nfsiso)[

ptions]:<server>:<path>
*/
void parseNfsHostPathOpts(char *url, char **host, char **path, char **opts) {
/* Skip over the leading nfs: if present. */
if (!strncmp(url, "nfs:", 4))
url += 4;
+ else if (!strncmp(url, "nfsiso:", 7))
+ url += 7;
logMessage(DEBUGLVL, "parseNfsHostPathOpts url: |%s|", url);
@@ -123,12 +123,14 @@ static int nfsGetSetup(char ** hostptr, char ** dirptr, char ** optsptr) {
*/
void parseNfsHostPathOpts(char *url, char **host, char **path, char **opts) {
- /* Skip over the leading nfs: if present. */
+ /* Skip over the leading nfs: or nfsiso: if present. */
if (!strncmp(url, "nfs:", 4))
url += 4;
--
1.7.6
_______________________________________________
Anaconda-devel-list mailing list
Anaconda-devel-list@redhat.com
https://www.redhat.com/mailman/listinfo/anaconda-devel-list